==> munit-remote-2.1.5-sources.jar: org/mule/munit/remote/api/configuration/ServerPluginConfiguration.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.api.configuration;

import java.util.Map;

import org.apache.commons.lang3.StringUtils;

import com.google.common.base.Preconditions;

/**
 * Defines a server plugin configuration
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class ServerPluginConfiguration {

  private String groupId;
  private String artifactId;
  private String version;
  private String baseVersion;
  private String type;
  private String classifier;
  private Map<String, String> properties;


  protected ServerPluginConfiguration(String groupId, String artifactId, String version, String baseVersion, String type,
                                      String classifier, Map<String, String> properties) {
    this.groupId = groupId;
    this.artifactId = artifactId;
    this.version = version;
    this.baseVersion = baseVersion;
    this.type = type;
    this.classifier = classifier;
    this.properties = properties;
  }

  public String getGroupId() {
    return groupId;
  }

  public String getArtifactId() {
    return artifactId;
  }

  public String getVersion() {
    return version;
  }

  public String getBaseVersion() {
    return baseVersion;
  }

  public String getType() {
    return type;
  }

  public String getClassifier() {
    return classifier;
  }

  public Map<String, String> getProperties() {
    return properties;
  }

  /**
   * Server Plugin Configuration Builder
   *
   * @author Mulesoft Inc.
   * @since 2.0.0
   */
  public static class ServerPluginConfigurationBuilder {

    private String groupId;
    private String artifactId;
    private String version;
    private String baseVersion;
    private String type = "jar";
    private String classifier;
    private Map<String, String> properties;

    public ServerPluginConfigurationBuilder withGroupId(String groupId) {
      Preconditions.checkArgument(StringUtils.isNotBlank(groupId), "Group Id cannot be blank");
      this.groupId = groupId;
      return this;
    }

    public ServerPluginConfigurationBuilder withArtifactId(String artifactId) {
      Preconditions.checkArgument(StringUtils.isNotBlank(artifactId), "Artifact Id cannot be blank");
      this.artifactId = artifactId;
      return this;
    }

    public ServerPluginConfigurationBuilder withVersion(String version) {
      Preconditions.checkArgument(StringUtils.isNotBlank(version), "Version cannot be blank");
      this.version = version;
      return this;
    }

    public ServerPluginConfigurationBuilder withBaseVersion(String baseVersion) {
      this.baseVersion = baseVersion;
      return this;
    }

    public ServerPluginConfigurationBuilder withType(String type) {
      Preconditions.checkArgument(StringUtils.isNotBlank(type), "Type cannot be blank");
      this.type = type;
      return this;
    }

    public ServerPluginConfigurationBuilder withClassifier(String classifier) {
      this.classifier = classifier;
      return this;
    }

    public ServerPluginConfigurationBuilder withProperties(Map<String, String> properties) {
      this.properties = properties;
      return this;
    }

    public ServerPluginConfiguration build() {
      Preconditions.checkArgument(StringUtils.isNotBlank(groupId), "Group Id cannot be blank");
      Preconditions.checkArgument(StringUtils.isNotBlank(artifactId), "Artifact Id cannot be blank");
      Preconditions.checkArgument(StringUtils.isNotBlank(version), "Version cannot be blank");
      return new ServerPluginConfiguration(groupId, artifactId, version, baseVersion, type, classifier, properties);
    }
  }
}

==> munit-remote-3.2.1-sources.jar: org/mule/munit/remote/api/configuration/ServerPluginConfiguration.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.api.configuration;

import java.util.Map;

import org.apache.commons.lang3.StringUtils;

import org.mule.munit.common.util.Preconditions;

/**
 * Defines a server plugin configuration
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class ServerPluginConfiguration {

  private String groupId;
  private String artifactId;
  private String version;
  private String baseVersion;
  private String type;
  private String classifier;
  private Map<String, String> properties;


  protected ServerPluginConfiguration(String groupId, String artifactId, String version, String baseVersion, String type,
                                      String classifier, Map<String, String> properties) {
    this.groupId = groupId;
    this.artifactId = artifactId;
    this.version = version;
    this.baseVersion = baseVersion;
    this.type = type;
    this.classifier = classifier;
    this.properties = properties;
  }

  public ServerPluginConfiguration() {};

  public String getGroupId() {
    return groupId;
  }

  public String getArtifactId() {
    return artifactId;
  }

  public String getVersion() {
    return version;
  }

  public String getBaseVersion() {
    return baseVersion;
  }

  public String getType() {
    return type;
  }

  public String getClassifier() {
    return classifier;
  }

  public Map<String, String> getProperties() {
    return properties;
  }

  /**
   * Server Plugin Configuration Builder
   *
   * @author Mulesoft Inc.
   * @since 2.0.0
   */
  public static class ServerPluginConfigurationBuilder {

    private String groupId;
    private String artifactId;
    private String version;
    private String baseVersion;
    private String type = "jar";
    private String classifier;
    private Map<String, String> properties;

    public ServerPluginConfigurationBuilder withGroupId(String groupId) {
      Preconditions.checkArgument(StringUtils.isNotBlank(groupId), "Group Id cannot be blank");
      this.groupId = groupId;
      return this;
    }

    public ServerPluginConfigurationBuilder withArtifactId(String artifactId) {
      Preconditions.checkArgument(StringUtils.isNotBlank(artifactId), "Artifact Id cannot be blank");
      this.artifactId = artifactId;
      return this;
    }

    public ServerPluginConfigurationBuilder withVersion(String version) {
      Preconditions.checkArgument(StringUtils.isNotBlank(version), "Version cannot be blank");
      this.version = version;
      return this;
    }

    public ServerPluginConfigurationBuilder withBaseVersion(String baseVersion) {
      this.baseVersion = baseVersion;
      return this;
    }

    public ServerPluginConfigurationBuilder withType(String type) {
      Preconditions.checkArgument(StringUtils.isNotBlank(type), "Type cannot be blank");
      this.type = type;
      return this;
    }

    public ServerPluginConfigurationBuilder withClassifier(String classifier) {
      this.classifier = classifier;
      return this;
    }

    public ServerPluginConfigurationBuilder withProperties(Map<String, String> properties) {
      this.properties = properties;
      return this;
    }

    public ServerPluginConfiguration build() {
      Preconditions.checkArgument(StringUtils.isNotBlank(groupId), "Group Id cannot be blank");
      Preconditions.checkArgument(StringUtils.isNotBlank(artifactId), "Artifact Id cannot be blank");
      Preconditions.checkArgument(StringUtils.isNotBlank(version), "Version cannot be blank");
      return new ServerPluginConfiguration(groupId, artifactId, version, baseVersion, type, classifier, properties);
    }
  }
}
